# This file contains lines mentioning frame files to install by icmstart(1)
# empty lines and lines starting with # are ignored.

# Files and directories are installed by tar, see icmstart(1)'s man-page
# Lines starting with P are not installed when 'icmstart xxx library' is
# issued.
# Lines starting with L are not installed when 'icmstart xxx program' is
# issued.
# User-confirmation is required for entries on lines having a ? following 
# the optional P or L.
# The b suffix to P/L specifies files which are not installed when calling
#   icmstart -b ...

    CLASSES
    icmconf
P   main.cc     
P   main.ih     
Pb  usage.cc
Pb  version.cc
 
P ? scanner
P ? parser
